@@ -28,6 +28,19 @@ Exception::Base - Lightweight exceptions
             message=>'Something wrong',
             filename=>'/etc/passwd');
   };
+  # syntax for Perl >= 5.10
+  use feature 'switch';
+  if ($@) {
+    given (my $e = Exception::Base->catch) {
+      when ($e->isa('Exception::IO')) { warn "IO problem"; }
+      when ($e->isa('Exception::Eval')) { warn "eval died"; }
+      when ($e->isa('Exception::Runtime')) { warn "some runtime was caught"; }
+      when ($e->matches({value=>9})) { warn "something happened"; }
+      when ($e->matches(qr/^Error/)) { warn "some error based on regex"; }
+      default { $e->throw; } # rethrow the exception
+    }
+  }
+  # standard syntax for older Perl
   if ($@) {
     my $e = Exception::Base->catch;   # convert $@ into exception
     if ($e->isa('Exception::IO')) { warn "IO problem"; }
@@ -141,7 +154,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.2202';
+our $VERSION = '0.23';
 
 use utf8;
 
@@ -235,8 +248,8 @@ Smart matching operator.  See C<matches> method.
   print 123 ~~ $@;                                # 1
   print {message=>"Message", value=>123} ~~ $@;   # 1
 
-Warning: The second argument for smart matching operator needs to be scalar
-for Perl 5.10.1 RC1.  This operator is going to change soon.
+Warning: The smart operator requires that the exception object is a second
+argument.
 
 =back
 
@@ -1067,11 +1080,14 @@ sub throw {
 };
 
 
-=item I<CLASS>-E<gt>catch
+=item I<CLASS>-E<gt>catch([$I<variable>])
 
-The exception is recovered from C<$@> variable and method returns an exception
-object if exception is caught or undefined value otherwise.  The C<$@>
-variable is replaced with empty string to avoid endless loop.
+The exception is recovered from I<variable> argument or C<$@> variable if
+I<variable> argument was empty.  Then also C<$@> is replaced with empty string
+to avoid an endless loop.
+
+The method returns an exception object if exception is caught or undefined
+value otherwise.
 
   eval { Exception::Base->throw; };
   if ($@) {
@@ -1100,10 +1116,16 @@ sub catch {
     my $new_e;
 
 
-    # Recover exception from $@ and clear it
-    ## no critic qw(RequireLocalizedPunctuationVars)
-    $e = $@;
-    $@ = '';
+    if (@_ > 1) {
+        # Recover exception from argument
+        $e = $_[1];
+    }
+    else {
+        # Recover exception from $@ and clear it
+        ## no critic qw(RequireLocalizedPunctuationVars)
+        $e = $@;
+        $@ = '';
+    };
 
     if (ref $e and do { local $@; local $SIG{__DIE__}; eval { $e->isa(__PACKAGE__) } }) {
         # Caught exception
@@ -1128,12 +1150,10 @@ sub catch {
 
 =item matches(I<that>)
 
-Checks if the exception object matches the given argument.  The C<matches>
-method overloads C<~~> smart matching operator, so it can be used with
-C<given> keyword.
+Checks if the exception object matches the given argument.
 
-Warning: The second argument for smart matching operator needs to be scalar
-for Perl 5.10.1 RC1.  This method is going to change soon.
+The C<matches> method overloads C<~~> smart matching operator.  Warning: The
+second argument for smart matching operator needs to be scalar.
 
 If the argument is a reference to array, it is checked if the object is a
 given class.
@@ -2132,6 +2152,7 @@ BEGIN {
  <<create>> +throw( args : Hash = undef )
  <<create>> +throw( message : Str, args : Hash = undef )
  +catch() : Exception::Base
+ +catch( variable : Any ) : Exception::Base
  +matches( that : Any ) : Bool                                 {overload="~~"}
  +to_string() : Str                                            {overload='""'}
  +to_number() : Num                                            {overload="0+"}
@@ -2192,8 +2213,11 @@ Not recommended.  Abadoned.  Modifies C<%SIG> handlers.
 
 =item L<TryCatch>
 
-Promising module which gives new try/catch keywords without source filter.
-Also it can use C<Exception::Base> exceptions.
+A module which gives new try/catch keywords without source filter.
+
+=item L<Try::Tiny>
+
+Smaller, simpler and slower version of L<TryCatch> module.
 
 =back
 
@@ -2203,6 +2227,9 @@ does not use closures as L<Error> and does not pollute namespace as
 L<Exception::Class::TryCatch>.  It is also much faster than
 L<Exception::Class::TryCatch> and L<Error> for success scenario.
 
+The C<Exception::Base> is compatible with syntax sugar modules like
+L<TryCatch> and L<Try::Tiny>.
+
 The C<Exception::Base> is also a base class for enhanced classes:
 
 =over
@@ -2264,54 +2291,50 @@ Success scenario should have no penalty on speed.  Failure scenario is usually
 more complex to handle and can be significally slower.
 
 Any other code than simple C<if ($@)> is really slow and shouldn't be used if
-speed is important.  It means that L<Error> and L<Exception::Class::TryCatch>
-should be avoided as far as they are slow by design.  The L<Exception::Class>
-module doesn't use C<if ($@)> syntax in its documentation so it was
-benchmarked with its default syntax, however it might be possible to convert
-it to simple C<if ($@)>.
+speed is important.  It means that any module which provides try/catch syntax
+sugar should be avoided: L<Error>, L<Exception::Class::TryCatch>, L<TryCatch>,
+L<Try::Tiny>.  Be careful because simple C<if ($@)> has many gotchas which are
+described in L<Try::Tiny>'s documentation.
 
 The C<Exception::Base> module was benchmarked with other implementations for
-simple try/catch scenario.  The results (Perl 5.10.1 i686-linux-thread-multi)
-are following:
+simple try/catch scenario.  The results
+(Perl 5.10.1 x86_64-linux-thread-multi) are following:
 
   -----------------------------------------------------------------------
   | Module                              | Success sub/s | Failure sub/s |
   -----------------------------------------------------------------------
-  | eval/die string                     |       2432775 |        331742 |
+  | eval/die string                     |       3715708 |        408951 |
   -----------------------------------------------------------------------
-  | eval/die object                     |       2646077 |        175847 |
+  | eval/die object                     |       4563524 |        191664 |
   -----------------------------------------------------------------------
-  | Exception::Base eval/if             |       2548294 |          9340 |
+  | Exception::Base eval/if             |       4903857 |         11291 |
   -----------------------------------------------------------------------
-  | Exception::Base eval/if verbosity=1 |       2680215 |         18741 |
+  | Exception::Base eval/if verbosity=1 |       4790762 |         18833 |
   -----------------------------------------------------------------------
-  | Error                               |        102426 |         22615 |
+  | Error                               |        117475 |         26694 |
   -----------------------------------------------------------------------
-  | Class::Throwable                    |       2680740 |          9560 |
+  | Class::Throwable                    |       4618545 |         12678 |
   -----------------------------------------------------------------------
-  | Exception::Class                    |        601571 |          2948 |
+  | Exception::Class                    |        643901 |          3493 |
   -----------------------------------------------------------------------
-  | Exception::Class::TryCatch          |        275985 |          2934 |
+  | Exception::Class::TryCatch          |        307825 |          3439 |
   -----------------------------------------------------------------------
-  | TryCatch                            |        721596 |        260654 |
+  | TryCatch                            |        690784 |        294802 |
+  -----------------------------------------------------------------------
+  | Try::Tiny                           |        268780 |        158383 |
   -----------------------------------------------------------------------
 
 The C<Exception::Base> module was written to be as fast as it is
 possible.  It does not use internally i.e. accessor functions which are
 slower about 6 times than standard variables.  It is slower than pure
-die/eval because it is uses OO mechanisms which are slow in Perl.  It
-can be a little faster if some features are disables, i.e. the stack
-trace and higher verbosity.
+die/eval for success scenario because it is uses OO mechanisms which are slow
+in Perl.  It can be a little faster if some features are disables, i.e. the
+stack trace and higher verbosity.
 
 You can find the benchmark script in this package distribution.
 
 =head1 BUGS
 
-The major incompatibility exists in Perl 5.10.1 RC1.  The smart match operator
-was changed and second argument needs to be a scalar.  It means that
-given/when syntax cannot be used with array or hash reference.  The C<match>
-method and overloaded smart match operator is going to change their behavior.
-
 If you find the bug, please report it.
 
 =for readme continue
